@@ -25,6 +25,7 @@
 #'
 #' head(fortify(f))
 #' autoplot(f, n = 5)
+#' plot(f, n = 5)
 autoplot.Filter = function(object, type = "boxplot", n = Inf, ...) { # nolint
   assert_string(type)
 
@@ -41,6 +42,14 @@ autoplot.Filter = function(object, type = "boxplot", n = Inf, ...) { # nolint
   )
 }
 
+#' @importFrom graphics plot
+#' @param x ([mlr3filters::Filter]).
+#' @rdname autoplot.Filter
+#' @export
+plot.Filter = function(x, ...) {
+  print(autoplot(x, ...))
+}
+
 #' @export
 fortify.Filter = function(model, data = NULL, ...) { # nolint
   as.data.table(model)
