@@ -30,6 +30,7 @@
 #' learner = lrn("regr.rpart", keep_model = TRUE)
 #' learner$train(task)
 #' autoplot(learner)
+#' plot(learner)
 autoplot.LearnerClassifRpart = function(object, ...) { # nolint
   if (is.null(object$model)) {
     stopf("Learner '%s' must be trained first", object$id)
@@ -42,3 +43,11 @@ autoplot.LearnerClassifRpart = function(object, ...) { # nolint
   autoplot(partykit::as.party(object$model), ...) +
     ggparty::geom_node_label(aes(label = paste0("n=", .data[["nodesize"]])), nudge_y = 0.03, ids = "terminal")
 }
+
+#' @importFrom graphics plot
+#' @param x ([mlr3::LearnerClassifRpart] | [mlr3::LearnerRegrRpart]).
+#' @rdname autoplot.LearnerClassifRpart
+#' @export
+plot.LearnerClassifRpart= function(x, ...) {
+  print(autoplot(x, ...))
+}
