@@ -18,3 +18,11 @@ autoplot.LearnerRegrRpart = function(object, ...) { # nolint
     )) +
     ggparty::geom_node_label(aes(label = paste0("n=", .data[["nodesize"]])), nudge_y = 0.03, ids = "terminal")
 }
+
+#' @importFrom graphics plot
+#' @param x ([mlr3::LearnerClassifRpart] | [mlr3::LearnerRegrRpart]).
+#' @rdname autoplot.LearnerClassifRpart
+#' @export
+plot.LearnerRegrRpart = function(x, ...) {
+  print(autoplot(x, ...))
+}
