@@ -37,6 +37,7 @@
 #'
 #' head(fortify(object))
 #' autoplot(object)
+#' plot(object)
 #' autoplot(object, type = "histogram", binwidth = 1)
 #' autoplot(object, type = "residual")
 autoplot.PredictionRegr = function(object, # nolint
@@ -79,3 +80,11 @@ autoplot.PredictionRegr = function(object, # nolint
     stopf("Unknown plot type '%s'", type)
   )
 }
+
+#' @importFrom graphics plot
+#' @param x ([mlr3::PredictionRegr]).
+#' @rdname autoplot.PredictionRegr
+#' @export
+plot.PredictionRegr = function(x, ...) {
+  print(autoplot(x, ...))
+}
